Journal Style Example Gallery
=============================

Below is a gallery of examples that show how to use the different styles and plotting utilities.
The examples mostly show how the stylesheets impact the visuals of the plots, but also show how to use the plotting utilities in a rudimentary way.
